==> jc-1.4.0.tar.gz: soot/coffi/Instruction__5fPutfield.h <==
// class soot.coffi.Instruction_Putfield

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 6e85d167db58e860 soot_coffi_Instruction__5fPutfield
// @dep_class d13384827121be19 soot_coffi_Instruction__5fintindex

// header file dependencies
// @dep_header soot_coffi_Instruction__5fintindex

#include "soot/coffi/Instruction__5fintindex.h"

#ifndef _JC_soot_coffi_Instruction__5fPutfield_H_
#define _JC_soot_coffi_Instruction__5fPutfield_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fPutfield$sub_refs	_jc_soot_coffi_Instruction__5fPutfield$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fPutfield$sub_nonrefs	_jc_soot_coffi_Instruction__5fPutfield$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fPutfield$refs	_jc_soot_coffi_Instruction__5fPutfield$refs;
typedef struct _jc_soot_coffi_Instruction__5fPutfield$nonrefs	_jc_soot_coffi_Instruction__5fPutfield$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fPutfield$object	_jc_soot_coffi_Instruction__5fPutfield$object;

typedef const struct _jc_soot_coffi_Instruction__5fPutfield$vmethods	_jc_soot_coffi_Instruction__5fPutfield$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fPutfield$vtable	_jc_soot_coffi_Instruction__5fPutfield$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fPutfield$vtype	_jc_soot_coffi_Instruction__5fPutfield$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fPutfield$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fPutfield$object *);

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fPutfield$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fPutfield$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fintindex$vmethods	soot_coffi_Instruction__5fintindex;
	_jc_soot_coffi_Instruction__5fPutfield$vmethods	soot_coffi_Instruction__5fPutfield;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fPutfield$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fPutfield$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fPutfield$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fPutfield$refs {
    _jc_soot_coffi_Instruction__5fPutfield$sub_refs	soot_coffi_Instruction__5fPutfield;
    _jc_soot_coffi_Instruction__5fintindex$sub_refs	soot_coffi_Instruction__5fintindex;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fPutfield$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fPutfield$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fintindex$sub_nonrefs	soot_coffi_Instruction__5fintindex;
    _jc_soot_coffi_Instruction__5fPutfield$sub_nonrefs	soot_coffi_Instruction__5fPutfield;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fPutfield$object {
	_jc_soot_coffi_Instruction__5fPutfield$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fPutfield$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fPutfield$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fPutfield$vtype _jc_soot_coffi_Instruction__5fPutfield$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fPutfield, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fPutfield$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fPutfield_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Instruction__5fPutfield.h <==
// class soot.coffi.Instruction_Putfield

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 6e85d167db58e860 soot_coffi_Instruction__5fPutfield
// @dep_class d13384827121be19 soot_coffi_Instruction__5fintindex

// header file dependencies
// @dep_header soot_coffi_Instruction__5fintindex

#include "soot/coffi/Instruction__5fintindex.h"

#ifndef _JC_soot_coffi_Instruction__5fPutfield_H_
#define _JC_soot_coffi_Instruction__5fPutfield_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fPutfield$sub_refs	_jc_soot_coffi_Instruction__5fPutfield$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fPutfield$sub_nonrefs	_jc_soot_coffi_Instruction__5fPutfield$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fPutfield$refs	_jc_soot_coffi_Instruction__5fPutfield$refs;
typedef struct _jc_soot_coffi_Instruction__5fPutfield$nonrefs	_jc_soot_coffi_Instruction__5fPutfield$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fPutfield$object	_jc_soot_coffi_Instruction__5fPutfield$object;

typedef const struct _jc_soot_coffi_Instruction__5fPutfield$vmethods	_jc_soot_coffi_Instruction__5fPutfield$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fPutfield$vtable	_jc_soot_coffi_Instruction__5fPutfield$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fPutfield$vtype	_jc_soot_coffi_Instruction__5fPutfield$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fPutfield$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fPutfield$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fPutfield$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fPutfield$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fintindex$vmethods	soot_coffi_Instruction__5fintindex;
	_jc_soot_coffi_Instruction__5fPutfield$vmethods	soot_coffi_Instruction__5fPutfield;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fPutfield$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fPutfield$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fPutfield$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fPutfield$refs {
    _jc_soot_coffi_Instruction__5fPutfield$sub_refs	soot_coffi_Instruction__5fPutfield;
    _jc_soot_coffi_Instruction__5fintindex$sub_refs	soot_coffi_Instruction__5fintindex;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fPutfield$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fPutfield$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fintindex$sub_nonrefs	soot_coffi_Instruction__5fintindex;
    _jc_soot_coffi_Instruction__5fPutfield$sub_nonrefs	soot_coffi_Instruction__5fPutfield;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fPutfield$object {
	_jc_soot_coffi_Instruction__5fPutfield$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fPutfield$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fPutfield$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fPutfield$vtype _jc_soot_coffi_Instruction__5fPutfield$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fPutfield, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fPutfield$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fPutfield_H_ */
